Performs SPM12 coregistration estimation and reslicing on an Image
spm12_coregister.deprecated(
fixed,
moving,
other.files = NULL,
prefix = "r",
add_spm_dir = TRUE,
spmdir = spm_dir(),
clean = TRUE,
verbose = TRUE,
outdir = NULL,
install_dir = NULL,
...
)File that is assumed fixed
moving file to be registered to fixed space
Other files to register to fixed, in same space as moving file
Prefix to append to front of image filename
Add SPM12 directory from this package
SPM dir to add, will use package default directory
Remove scripts from temporary directory after running
Print diagnostic messages
Directory to copy results. If full filename given,
then results will
be in dirname(filename)
directory to download SPM12
Arguments passed to run_spm12_script
Result from run_matlab_script